# Generated by roxygen2: do not edit by hand

S3method(plot,ssadfit)
S3method(predict,ssadfit)
S3method(print,ssadfit)
S3method(summary,ssadfit)
export(geweke_diag)
export(ssad_fit)
export(ssad_gamma)
export(ssad_reliability)
export(ssad_simulate)
export(ssad_wiener)
importFrom(grDevices,rainbow)
importFrom(graphics,abline)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(utils,head)
