#' Wiener-Arrhenius Step-Stress Accelerated Degradation Data
#'
#' Simulated degradation dataset generated using a Wiener process with an Arrhenius
#' acceleration model under a 3-step step-stress accelerated degradation test (SSADT).
#' Originally published in Table 2 of Pan and Balakrishnan (2010).
#'
#' @format A data frame with 30 rows and 6 variables:
#' \describe{
#'   \item{time}{Inspection time in hours (72 to 2160 hours).}
#'   \item{unit1}{Degradation measurements for test unit 1.}
#'   \item{unit2}{Degradation measurements for test unit 2.}
#'   \item{unit3}{Degradation measurements for test unit 3.}
#'   \item{unit4}{Degradation measurements for test unit 4.}
#'   \item{unit5}{Degradation measurements for test unit 5.}
#' }
#' @source Pan, Z., & Balakrishnan, N. (2010). Multiple-Steps Step-Stress Accelerated Degradation Modeling Based on Wiener and Gamma Processes. \emph{Communications in Statistics - Simulation and Computation}, 39(7), 1384-1402. \doi{10.1080/03610918.2010.496060}
#' @docType data
#' @keywords datasets
#' @name wiener_arrhenius
#' @usage data(wiener_arrhenius)
#' @examples
#' data(wiener_arrhenius)
#' head(wiener_arrhenius)
"wiener_arrhenius"

#' Wiener-Power Step-Stress Accelerated Degradation Data
#'
#' Simulated degradation dataset generated using a Wiener process with a Power
#' acceleration model under a 3-step step-stress accelerated degradation test (SSADT).
#' Originally published in Table 3 of Pan and Balakrishnan (2010).
#'
#' @format A data frame with 30 rows and 6 variables:
#' \describe{
#'   \item{time}{Inspection time in hours (72 to 2160 hours).}
#'   \item{unit1}{Degradation measurements for test unit 1.}
#'   \item{unit2}{Degradation measurements for test unit 2.}
#'   \item{unit3}{Degradation measurements for test unit 3.}
#'   \item{unit4}{Degradation measurements for test unit 4.}
#'   \item{unit5}{Degradation measurements for test unit 5.}
#' }
#' @source Pan, Z., & Balakrishnan, N. (2010). Multiple-Steps Step-Stress Accelerated Degradation Modeling Based on Wiener and Gamma Processes. \emph{Communications in Statistics - Simulation and Computation}, 39(7), 1384-1402. \doi{10.1080/03610918.2010.496060}
#' @docType data
#' @keywords datasets
#' @name wiener_power
#' @usage data(wiener_power)
#' @examples
#' data(wiener_power)
#' head(wiener_power)
"wiener_power"

#' Gamma-Arrhenius Step-Stress Accelerated Degradation Data
#'
#' Simulated degradation dataset generated using a Gamma process with an Arrhenius
#' acceleration model under a 3-step step-stress accelerated degradation test (SSADT).
#' Originally published in Table 4 of Pan and Balakrishnan (2010).
#'
#' @format A data frame with 30 rows and 6 variables:
#' \describe{
#'   \item{time}{Inspection time in hours (72 to 2160 hours).}
#'   \item{unit1}{Degradation measurements for test unit 1.}
#'   \item{unit2}{Degradation measurements for test unit 2.}
#'   \item{unit3}{Degradation measurements for test unit 3.}
#'   \item{unit4}{Degradation measurements for test unit 4.}
#'   \item{unit5}{Degradation measurements for test unit 5.}
#' }
#' @source Pan, Z., & Balakrishnan, N. (2010). Multiple-Steps Step-Stress Accelerated Degradation Modeling Based on Wiener and Gamma Processes. \emph{Communications in Statistics - Simulation and Computation}, 39(7), 1384-1402. \doi{10.1080/03610918.2010.496060}
#' @docType data
#' @keywords datasets
#' @name gamma_arrhenius
#' @usage data(gamma_arrhenius)
#' @examples
#' data(gamma_arrhenius)
#' head(gamma_arrhenius)
"gamma_arrhenius"

#' Gamma-Power Step-Stress Accelerated Degradation Data
#'
#' Simulated degradation dataset generated using a Gamma process with a Power
#' acceleration model under a 3-step step-stress accelerated degradation test (SSADT).
#' Originally published in Table 5 of Pan and Balakrishnan (2010).
#'
#' @format A data frame with 30 rows and 6 variables:
#' \describe{
#'   \item{time}{Inspection time in hours (72 to 2160 hours).}
#'   \item{unit1}{Degradation measurements for test unit 1.}
#'   \item{unit2}{Degradation measurements for test unit 2.}
#'   \item{unit3}{Degradation measurements for test unit 3.}
#'   \item{unit4}{Degradation measurements for test unit 4.}
#'   \item{unit5}{Degradation measurements for test unit 5.}
#' }
#' @source Pan, Z., & Balakrishnan, N. (2010). Multiple-Steps Step-Stress Accelerated Degradation Modeling Based on Wiener and Gamma Processes. \emph{Communications in Statistics - Simulation and Computation}, 39(7), 1384-1402. \doi{10.1080/03610918.2010.496060}
#' @docType data
#' @keywords datasets
#' @name gamma_power
#' @usage data(gamma_power)
#' @examples
#' data(gamma_power)
#' head(gamma_power)
"gamma_power"
