% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{wiener_power}
\alias{wiener_power}
\title{Wiener-Power Step-Stress Accelerated Degradation Data}
\format{
A data frame with 30 rows and 6 variables:
\describe{
  \item{time}{Inspection time in hours (72 to 2160 hours).}
  \item{unit1}{Degradation measurements for test unit 1.}
  \item{unit2}{Degradation measurements for test unit 2.}
  \item{unit3}{Degradation measurements for test unit 3.}
  \item{unit4}{Degradation measurements for test unit 4.}
  \item{unit5}{Degradation measurements for test unit 5.}
}
}
\source{
Pan, Z., & Balakrishnan, N. (2010). Multiple-Steps Step-Stress Accelerated Degradation Modeling Based on Wiener and Gamma Processes. \emph{Communications in Statistics - Simulation and Computation}, 39(7), 1384-1402. \doi{10.1080/03610918.2010.496060}
}
\usage{
data(wiener_power)
}
\description{
Simulated degradation dataset generated using a Wiener process with a Power
acceleration model under a 3-step step-stress accelerated degradation test (SSADT).
Originally published in Table 3 of Pan and Balakrishnan (2010).
}
\examples{
data(wiener_power)
head(wiener_power)
}
\keyword{datasets}
