% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simulation.R
\name{ssad_simulate}
\alias{ssad_simulate}
\title{Simulate Step-Stress Accelerated Degradation Data}
\usage{
ssad_simulate(
  n_units = 5,
  times = seq(72, 2160, by = 72),
  stress_levels = c(45, 65, 85),
  thresholds = c(90, 160),
  process = c("wiener", "gamma"),
  model = c("arrhenius", "power"),
  params
)
}
\arguments{
\item{n_units}{Number of test units (e.g. 5).}

\item{times}{Vector of inspection time points (e.g. \code{seq(72, 2160, by = 72)}).}

\item{stress_levels}{Vector of stress levels S = (S1, S2, ..., SK).}

\item{thresholds}{Vector of degradation thresholds (omega_1, ..., omega_K-1) at which stress is elevated.}

\item{process}{Character string specifying \code{"wiener"} or \code{"gamma"}.}

\item{model}{Acceleration model: \code{"arrhenius"} or \code{"power"}.}

\item{params}{Model parameters: \code{c(a, b, sigma)} for Wiener, or \code{c(a, b, u)} for Gamma.}
}
\value{
A data frame with columns \code{time}, \code{unit1}, \code{unit2}, ..., \code{unitN}.
}
\description{
Generates simulated degradation path data for N test units subject to a K-steps step-stress
accelerated degradation test (SSADT) under Wiener or Gamma stochastic process models.
}
\examples{
set.seed(42)
sim_data <- ssad_simulate(
  n_units = 5,
  times = seq(72, 2160, by = 72),
  stress_levels = c(45, 65, 85),
  thresholds = c(90, 160),
  process = "wiener",
  model = "arrhenius",
  params = c(a = 5.3669, b = -2546.7, sigma = 0.1)
)
head(sim_data)
}
\references{
Pan, Z., & Balakrishnan, N. (2010). Multiple-Steps Step-Stress Accelerated Degradation Modeling Based on Wiener and Gamma Processes.
\emph{Communications in Statistics - Simulation and Computation}, 39(7), 1384-1402. \doi{10.1080/03610918.2010.496060}
}
