% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{print.ssadfit}
\alias{print.ssadfit}
\title{Print Method for Step-Stress Accelerated Degradation Fit}
\usage{
\method{print}{ssadfit}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"ssadfit"}.}

\item{...}{Additional arguments passed to print.}
}
\value{
Invisibly returns the input object \code{x}.
}
\description{
Prints a concise summary of the fitted step-stress accelerated degradation model.
}
\examples{
data(wiener_arrhenius)
fit <- ssad_fit(wiener_arrhenius, process = "wiener", model = "arrhenius", method = "mle")
print(fit)
}
