% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/wiener_ssad.R
\name{ssad_wiener}
\alias{ssad_wiener}
\title{Wiener Process Step-Stress Accelerated Degradation Model Estimation}
\usage{
ssad_wiener(
  data,
  stress_levels = c(45, 65, 85),
  thresholds = c(90, 160),
  model = c("arrhenius", "power"),
  method = c("mle", "mcmc"),
  init = NULL,
  n_iter = 5000,
  burnin = 1000,
  thin = 1
)
}
\arguments{
\item{data}{A data frame containing inspection times in the first column and unit degradation measurements in subsequent columns,
or a long-format data frame with columns \code{unit}, \code{time}, \code{degradation}.}

\item{stress_levels}{Vector of stress levels S = (S1, S2, ..., SK).}

\item{thresholds}{Vector of degradation thresholds (omega_1, ..., omega_K-1) at which stress levels are elevated.}

\item{model}{Acceleration model: \code{"arrhenius"} or \code{"power"}.}

\item{method}{Estimation method: \code{"mle"} or \code{"mcmc"}.}

\item{init}{Initial parameter values \code{c(a, b, sigma)}.}

\item{n_iter}{Number of MCMC iterations (default: 10000).}

\item{burnin}{Number of burn-in iterations (default: 2000).}

\item{thin}{Thinning interval for MCMC (default: 1).}
}
\value{
An object of class \code{"ssadfit"} containing fit results, parameter estimates, log-likelihood, MCMC samples (if applicable), and metadata.
}
\description{
Fits a Wiener process step-stress accelerated degradation model using Maximum Likelihood Estimation (MLE)
or Bayesian Markov Chain Monte Carlo (MCMC) as described in Pan and Balakrishnan (2010).
}
\examples{
data(wiener_arrhenius)
fit_w <- ssad_wiener(
  data = wiener_arrhenius,
  stress_levels = c(45, 65, 85),
  thresholds = c(90, 160),
  model = "arrhenius",
  method = "mle"
)
print(fit_w)
}
\references{
Pan, Z., & Balakrishnan, N. (2010). Multiple-Steps Step-Stress Accelerated Degradation Modeling Based on Wiener and Gamma Processes.
\emph{Communications in Statistics - Simulation and Computation}, 39(7), 1384-1402. \doi{10.1080/03610918.2010.496060}
}
